# RSL-RL Maintainers and Contributors

This is the official list of developers and contributors.

To see the full list of contributors, see the revision history in the source control.

Names should be added to this file as: individual names or organizations.

Email addresses are tracked elsewhere to avoid spam.

Please keep the lists sorted alphabetically.

## Maintainers

* Robotic Systems Lab, ETH Zurich
* NVIDIA Corporation

---

* Mayank Mittal
* Clemens Schwarke

## Authors

* David Hoeller
* Nikita Rudin

## Contributors

* Bikram Pandit
* Eric Vollenweider
* Fabian Jenelten
* Lorenzo Terenzi
* Marko Bjelonic
* Matthijs van der Boon
* Pascal Roth
* Zhang Chong
* Ziqi Fan
